class puppet_enterprise::console(
  $database_host,
  $master_host,
  $ca_host,
  $puppetdb_host,
  $delayed_job_workers,
  $console_server_certname  = $::clientcert,
  $console_client_certname  = $puppet_enterprise::params::console_client_certname,
  $classifier_host          = $::clientcert,
  $classifier_port          = $puppet_enterprise::params::console_services_api_ssl_listen_port,
  $certname                 = $::clientcert,
  $rbac_host                = $::clientcert,
  $rbac_port                = $puppet_enterprise::params::console_services_api_ssl_listen_port,
  $database_name            = $puppet_enterprise::params::console_database_name,
  $database_user            = $puppet_enterprise::params::console_database_user,
  $database_password        = $puppet_enterprise::params::console_database_password,
  $database_port            = $puppet_enterprise::params::database_port,
  $puppetdb_port            = $puppet_enterprise::params::puppetdb_ssl_listen_port,
  $listen_address           = $puppet_enterprise::params::plaintext_address,
  $listen_port              = $puppet_enterprise::params::dashboard_listen_port,
  $ssl_listen_address       = $puppet_enterprise::params::ssl_address,
  $ssl_listen_port          = $puppet_enterprise::params::dashboard_ssl_listen_port,
  $localcacert              = $puppet_enterprise::params::localcacert,
  $hostcrl                  = $puppet_enterprise::params::hostcrl,
  $lm_discovery_timeout     = undef,
  $lm_inventory_retries     = undef,
  $disable_live_management  = true,
  $migrate_db               = true,
  $secret_token             = '',
) inherits puppet_enterprise::params {

  class { 'puppet_enterprise::console::config':
    ca_host                 => $ca_host,
    master_host             => $master_host,
    puppetdb_host           => $puppetdb_host,
    puppetdb_port           => $puppetdb_port,
    secret_token            => $secret_token,
    localcacert             => $localcacert,
    hostcrl                 => $hostcrl,
    console_server_certname => $console_server_certname,
    console_client_certname => $console_client_certname,
    classifier_host         => $classifier_host,
    classifier_port         => $classifier_port,
    certname                => $certname,
    ssl_listen_port         => $ssl_listen_port,
    before                  => Class['puppet_enterprise::console::database'],
    disable_live_management => $disable_live_management,
    delayed_job_workers     => $delayed_job_workers,
    lm_discovery_timeout   => $lm_discovery_timeout,
    lm_inventory_retries   => $lm_inventory_retries,
  }

  class { 'puppet_enterprise::console::console_auth_config':
    console_server_certname => $console_server_certname,
    rbac_host               => $rbac_host,
    rbac_port               => $rbac_port,
    before                  => Class['puppet_enterprise::console::database'],
  }

  class { 'puppet_enterprise::console::database':
    database_name     => $database_name,
    database_user     => $database_user,
    database_password => $database_password,
    database_host     => $database_host,
    database_port     => $database_port,
    migrate_db        => $migrate_db,
  }

  class { 'puppet_enterprise::console::service': }
}
