require 'spec_helper'

describe 'puppet_enterprise::puppetdb' do
  before :all do
    @facter_facts = {
      'osfamily'          => 'Debian',
      'operatingsystem'   => 'Debian',
      'fqdn'              => 'puppetdb.local.domain',
    }

    @params = {
      'certname'          => 'puppetdb.local.domain',
      'database_host'     => 'database.local.domain',
      'database_password' => 'password',
    }
  end

  let(:facts) { @facter_facts }
  let(:params) { @params }
  let(:sharedir) { '/opt/puppet/share/puppet-dashboard' }
  let(:ssldir) { '/etc/puppetlabs/puppet/ssl' }

  context "when managing packages" do
    it { should contain_package('pe-java') }
    it { should contain_package('pe-puppetdb') }
  end

  context "when managing default java_args" do
    it { should contain_pe_ini_subsetting("pe-puppetdb_'Xmx'").with_value( '256m' ) }
    it { should contain_pe_ini_subsetting("pe-puppetdb_'Xms'").with_value( '256m' ) }
  end

  context "wth custom java_args" do
    before(:all) { @params['java_args'] = { 'Xmx' => '128m' } }
    it { should contain_pe_ini_subsetting("pe-puppetdb_'Xmx'").with(
     'value'   => '128m',
     'require' => 'Package[pe-puppetdb]',
    ) }
  end

  it { should contain_class('puppet_enterprise::puppetdb::database_ini') }
  it { should contain_class('puppet_enterprise::puppetdb::jetty_ini') }
  it { should contain_class('puppet_enterprise::puppetdb::service') }
  it { should contain_file('/var/log/pe-puppetdb/').with(
    'ensure' => 'directory',
    'owner'  => 'pe-puppetdb',
    'group'  => 'pe-puppetdb',
    'mode'   => '0640'
  )}
  it { should contain_file('/var/log/pe-puppetdb/pe-puppetdb.log').with(
    'ensure'  => 'present',
    'owner'   => 'pe-puppetdb',
    'group'   => 'pe-puppetdb',
    'mode'    => '0640',
  )}
end
